<template>
    <div class="system-gas-container">
        <el-card shadow="hover">
            <div class="system-menu-search mb15">
                <el-form :inline="true" >
                    <el-form-item label="区域名称：">
                        <el-input  v-model="state.tableData.listQuery.searchParams.name"  placeholder="区域名称" ></el-input>
                    </el-form-item>
                    <el-button size="default" type="primary" class="ml10" @click="search()">
                        <el-icon>
                            <ele-Search />
                        </el-icon>
                        查询
                    </el-button>
                    <el-button size="default" class="ml10" @click="reset()">
                        <el-icon>
                            <RefreshLeft />
                        </el-icon>
                        重置
                    </el-button>
                </el-form>
            </div>
            <el-button size="default" class="mb10" type="success" @click="openDialog('新增',{})">
                <el-icon>
                    <ele-FolderAdd />
                </el-icon>
                新增区域
            </el-button>

            <el-table :data="state.tableData.data" style="width: 100%">
                <el-table-column align="center" prop="areaName" label="区域名称"/>
                <el-table-column align="center"  label="区域经纬度">
                    <template #default="scope">
                        <div v-for="(item, index) in scope.row.areaLngLat" :key="index">
                            [ {{item.lng}} , {{item.lat}} ]
                        </div>
                    </template>
                </el-table-column>
                <el-table-column label="操作" show-overflow-tooltip width="140">
                    <template #default="scope">
                        <el-button size="small" text type="primary" @click="openDialog('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" @click="openDialog('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" @click="del(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination
                @size-change="onHandleSizeChange"
                @current-change="onHandleCurrentChange"
                class="page-position"
                :pager-count="5"
                :page-sizes="[10, 20, 30]"
                v-model:current-page="state.tableData.listQuery.pageIndex"
                background
                v-model:page-size="state.tableData.listQuery.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="state.tableData.total">
            </el-pagination>
            <br />
            <br />
        </el-card>
        <area-dialog ref="areaRef" @getAreaData="initAreaData"></area-dialog>
    </div>
</template>

<script setup lang="ts">
import {reactive, ref, onMounted} from "vue";
import { TableDataState } from "/@/types/areaManage";
import areaDialog from "./component/areaDialog.vue";
import {ElMessage, ElMessageBox} from "element-plus";
import {areaManageApi} from "/@/api/basicDataManage/areaManage";

const areaRef = ref();
const state = reactive<TableDataState>({
    tableData: {
        data: [],
        total: 0,
        loading: false,
        listQuery: {
            pageIndex: 1,
            pageSize: 10,
            searchParams:{
                name: ''
            }
        }
    }
});

//页面加载
onMounted(() => {
    initAreaData();
});

const initAreaData = async () => {
    let res = await areaManageApi().getAreaPage(state.tableData.listQuery);
    if(res.data.code == 100) {
        if(res.data.data && res.data.data.length > 0) {
            state.tableData.data = res.data.data.map((item: any) => {
                return {
                    id: item.id,
                    areaName: item.name,
                    areaLngLat: item.regionLngLats,
                    areaColor: item.color
                }
            });
        }else {
            state.tableData.data = [];
        }
        state.tableData.total = res.data.total;
        state.tableData.listQuery.pageIndex = res.data.pageIndex;
        state.tableData.listQuery.pageSize = res.data.pageSize;
    }else {
        ElMessage({
            type: 'warning',
            message: res.data.msg
        });
    }
    console.log("数据列表")
};
const onHandleSizeChange = (val: number) => {
    state.tableData.listQuery.pageSize = val;
    initAreaData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
    state.tableData.listQuery.pageIndex = val;
    initAreaData();
};
const openDialog = (type: string, value: any) => {
    areaRef.value.openDialog(type, value);
};
const del = (val: any) => {
    ElMessageBox.confirm(
        '确定删除此条数据？',
        '提示',
        {
            confirmButtonText: '确定',
            cancelButtonText: '取消',
            type: 'warning',
        })
        .then( async() => {
            let res = await areaManageApi().delArea({id: val.id});
            if(res.data.code == 100) {
                ElMessage({
                    type: 'success',
                    message: '删除成功',
                });
                reset();
            }else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        })
};
const search = () => {
    state.tableData.listQuery.pageIndex = 1;
    initAreaData();
}
const reset = () => {
    state.tableData.listQuery.pageIndex = 1;
    state.tableData.listQuery.searchParams.name = '';
    initAreaData();
}
</script>
<style scoped lang="scss">

</style>